@@ -21,13 +21,9 @@
 
 from pybtex.backends import BaseBackend
 
-file_extension = 'txt'
 
 class Backend(BaseBackend):
-    name = 'plaintext'
-    aliases = 'text',
-    suffixes = '.txt',
-
+    default_suffix = '.txt'
     symbols = {
         'ndash': u'-',
         'newblock': u' ',
@@ -36,6 +32,9 @@ class Backend(BaseBackend):
     
     def format_tag(self, tag_name, text):
         return text
+
+    def format_href(self, url, text):
+        return text
     
     def write_entry(self, key, label, text):
         self.output(u"[%s] " % label)
