@@ -51,6 +51,7 @@ def make_bibliography(aux_filename,
     base_filename = path.splitext(aux_filename)[0]
     bbl_filename = base_filename + path.extsep + 'bbl'
     bib_filenames = [filename + bib_format.default_suffix for filename in aux_data.data]
-    bbl_file = pybtex.io.open_unicode(bbl_filename, 'w', encoding=output_encoding)
     interpreter = Interpreter(bib_format, bib_encoding)
-    interpreter.run(bst_script, aux_data.citations, bib_filenames, bbl_file, min_crossrefs=min_crossrefs)
+    bbl_data = interpreter.run(bst_script, aux_data.citations, bib_filenames, min_crossrefs=min_crossrefs)
+    with pybtex.io.open_unicode(bbl_filename, 'w', encoding=output_encoding) as bbl_file:
+        bbl_file.write(bbl_data)
