@@ -249,6 +249,39 @@ def bibtex_len(string):
     return length
 
 
+def bibtex_width(string):
+    r"""
+    Determine the width of the given string, in relative units.
+
+    >>> bibtex_width('')
+    0
+    >>> bibtex_width('abc')
+    1500
+    >>> bibtex_width('ab{c}')
+    2500
+    >>> bibtex_width(r"ab{\'c}")
+    1500
+    >>> bibtex_width(r"ab{\'c{}}")
+    1500
+    >>> bibtex_width(r"ab{\'c{}")
+    1500
+    >>> bibtex_width(r"ab{\'c{d}}")
+    2056
+    """
+
+    from pybtex.charwidths import charwidths
+    width = 0
+    for token, brace_level in scan_bibtex_string(string):
+        if brace_level == 1 and token.startswith('\\'):
+            for char in token[2:]:
+                if char not in '{}':
+                    width += charwidths.get(char, 0)
+            width -= 1000  # two braces
+        else:
+            width += charwidths.get(token, 0)
+    return width
+
+
 def bibtex_prefix(string, num_chars):
     """Return the firxt num_char characters of the string.
 
@@ -447,3 +480,27 @@ def bibtex_first_letter(string):
         elif char.isalpha():
             return char
     return ''
+
+
+def bibtex_abbreviate(string, delimiter=None, separator='-'):
+    """
+    Abbreviate string.
+
+    >>> print bibtex_abbreviate('Andrew Blake')
+    A
+    >>> print bibtex_abbreviate('Jean-Pierre')
+    J.-P
+    >>> print bibtex_abbreviate('Jean--Pierre')
+    J.-P
+    
+    """
+
+    def _bibtex_abbreviate():
+        for token in split_tex_string(string, sep=separator):
+            letter = bibtex_first_letter(token)
+            if letter:
+                yield letter
+
+    if delimiter is None:
+        delimiter = '.-'
+    return delimiter.join(_bibtex_abbreviate())
