@@ -86,7 +86,7 @@ class Writer(BaseWriter):
 
         for key, entry in bib_data.entries.iteritems():
             w.start('bibtex:entry', dict(id=key))
-            w.start('bibtex:' + entry.type)
+            w.start('bibtex:' + entry.original_type)
             for field_name, field_value in entry.fields.iteritems():
                 w.element('bibtex:' + field_name, field_value)
             for role, persons in entry.persons.iteritems():
