@@ -1,5 +1,5 @@
-# Copyright (c) 2009, 2010, 2011  Andrey Golovizin
-# 
+# Copyright (c) 2009, 2010, 2011, 2012  Andrey Golovizin
+#
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
 # "Software"), to deal in the Software without restriction, including
@@ -7,10 +7,10 @@
 # distribute, sublicense, and/or sell copies of the Software, and to
 # permit persons to whom the Software is furnished to do so, subject to
 # the following conditions:
-# 
+#
 # The above copyright notice and this permission notice shall be
 # included in all copies or substantial portions of the Software.
-# 
+#
 # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 # EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 # MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
@@ -20,4 +20,15 @@
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 class PybtexError(Exception):
-    pass
+    def __init__(self, message, filename=None):
+        super(PybtexError, self).__init__(message)
+        self.filename = filename
+
+    def get_context(self):
+        """Return extra error context info."""
+        return None
+
+    def get_filename(self):
+        """Return filename, if relevant."""
+        return self.filename
+
