@@ -24,7 +24,7 @@ from pybtex.style.labels import BaseLabelStyle
 
 
 class LabelStyle(BaseLabelStyle):
-    name = 'number'
 
-    def format(self, entry):
-        return unicode(entry.number)
+    def format_labels(self, sorted_entries):
+        for number, entry in enumerate(sorted_entries):
+            yield unicode(number + 1)
