@@ -150,7 +150,7 @@ class AtTest(ParserTest, TestCase):
         'Me2009': Entry('article', {'title': 'A @tey short story'}),
     })
     errors = [
-        "Syntax error in line 2: '(' or '{' expected",
+        "syntax error in line 2: '(' or '{' expected",
     ]
 
 class EntryTypesTest(ParserTest, TestCase):
@@ -178,10 +178,10 @@ class EntryTypesTest(ParserTest, TestCase):
         'aa2_id': Entry('_t'),
     })
     errors = [
-        "Syntax error in line 12: a valid name expected",
-        "Syntax error in line 13: '(' or '{' expected",
-        "Syntax error in line 14: '(' or '{' expected",
-        "Syntax error in line 15: '(' or '{' expected",
+        "syntax error in line 12: a valid name expected",
+        "syntax error in line 13: '(' or '{' expected",
+        "syntax error in line 14: '(' or '{' expected",
+        "syntax error in line 15: '(' or '{' expected",
     ]
 
 
@@ -218,9 +218,9 @@ class FieldNamesTest(ParserTest, TestCase):
         '2017': Entry('article', {'@name': 'Myself'}),
     })
     errors = [
-        "Syntax error in line 5: '}' expected",
-        "Syntax error in line 11: '=' expected",
-        'Syntax error in line 14: \'}\' expected',
+        "syntax error in line 5: '}' expected",
+        "syntax error in line 11: '=' expected",
+        'syntax error in line 14: \'}\' expected',
     ]
 
 
@@ -250,8 +250,8 @@ class InlineCommentTest(ParserTest, TestCase):
         'Me2013': Entry('article'),
     })
     errors = [
-        "Syntax error in line 10: '}' expected",
-        "Syntax error in line 12: '}' expected",
+        "syntax error in line 10: '}' expected",
+        "syntax error in line 12: '}' expected",
     ]
 
 
@@ -316,7 +316,7 @@ class KeyParsingTest(ParserTest, TestCase):
         'test(braces2)': Entry('article'),
     })
     errors = [
-        "Syntax error in line 5: ')' expected",
+        "syntax error in line 5: ')' expected",
     ]
 
 
@@ -361,7 +361,7 @@ class MacrosTest(ParserTest, TestCase):
         'gsl': Entry('article', persons={u'author': [Person(u'Gough, Brian'), Person(u'{et al.}')]}),
     })
     errors = [
-        'Undefined string in line 6: nobody',
+        'undefined string in line 6: nobody',
     ]
 
 
@@ -373,7 +373,7 @@ class WantedEntriesTest(ParserTest, TestCase):
         )
     """
     correct_result = BibliographyData(entries={
-        'gsl': Entry('article'),
+        'GSL': Entry('article'),
     })
 
 
@@ -385,12 +385,28 @@ class CrossrefTest(ParserTest, TestCase):
         @Journal{the_journal,}
     """
     correct_result = BibliographyData(entries={
-        'gsl': Entry('article', {'crossref': 'the_journal'}),
-        'gsl2': Entry('article', {'crossref': 'The_Journal'}),
+        'GSL': Entry('article', {'crossref': 'the_journal'}),
+        'GSL2': Entry('article', {'crossref': 'The_Journal'}),
         'the_journal': Entry('journal'),
     })
 
 
+class CrossrefWantedTest(ParserTest, TestCase):
+    """When cross-referencing an explicitly cited, the key from .aux file should be used."""
+
+    parser_options = {'wanted_entries': ['GSL', 'GSL2', 'The_Journal']}
+    input_string = u"""
+        @Article(gsl, crossref="the_journal")
+        @Article(gsl2, crossref="The_Journal")
+        @Journal{the_journal,}
+    """
+    correct_result = BibliographyData(entries={
+        'GSL': Entry('article', {'crossref': 'the_journal'}),
+        'GSL2': Entry('article', {'crossref': 'The_Journal'}),
+        'The_Journal': Entry('journal'),
+    })
+
+
 class UnusedEntryTest(ParserTest, TestCase):
     parser_options = {'wanted_entries': []}
     input_string = u"""
@@ -420,6 +436,7 @@ class CrossFileMacrosTest(ParserTest, TestCase):
         ),
     })
 
+
 class AtCharacterTest(ParserTest, TestCase):
     input_strings = [
         ur""",
@@ -437,3 +454,37 @@ class AtCharacterTest(ParserTest, TestCase):
             },
         ),
     })
+
+
+class AtCharacterInUnwantedEntryTest(ParserTest, TestCase):
+    parser_options = {'wanted_entries': []}
+    input_strings = [
+        ur""",
+            @proceedings{acc,
+                title = {Proc.\@ of the American Control Conference},
+                notes = "acc@example.org"
+            }
+        """,
+    ]
+    correct_result = BibliographyData()
+
+
+class CaseSensitivityTest(ParserTest, TestCase):
+    input_strings = [
+        ur""",
+            @Article{CamelCase,
+                Title = {To CamelCase or Under score},
+                year = 2009,
+                NOTES = "none"
+            }
+        """,
+    ]
+    correct_result = BibliographyData({
+        'CamelCase': Entry('article', 
+            fields={
+                'Title': 'To CamelCase or Under score',
+                'year': '2009',
+                'NOTES': 'none',
+            },
+        ),
+    })
