@@ -22,6 +22,7 @@
 from copy import deepcopy
 from unittest import TestCase
 from io import BytesIO, TextIOWrapper, BufferedWriter
+import pickle
 
 from .data import reference_data
 
@@ -31,7 +32,7 @@ class DatabaseIOTest(TestCase):
     def setUp(self):
         self.reference_data = deepcopy(reference_data)
         self.assertTrue(self.reference_data.entries)
-        self.assertTrue(self.reference_data.preamble())
+        self.assertTrue(self.reference_data.get_preamble())
 
     def _test_input(self, plugin):
         parser = find_plugin('pybtex.database.input', plugin)(encoding='UTF-8')
@@ -45,6 +46,9 @@ class DatabaseIOTest(TestCase):
         parser.parse_stream(parser_stream)
         loaded_data = parser.data
         self.assertEqual(loaded_data, self.reference_data)
+        self.assertEqual(pickle.loads(pickle.dumps(loaded_data, 0)), self.reference_data)
+        self.assertEqual(pickle.loads(pickle.dumps(loaded_data, 1)), self.reference_data)
+        self.assertEqual(pickle.loads(pickle.dumps(loaded_data, 2)), self.reference_data)
 
     def test_bibtex_input(self):
         self._test_input('bibtex')
